@@ -1,10 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 #****************************************************************************
 # cmdline.py, provides a class to read and execute command line arguments
 #
 # ConvertAll, a units conversion program
-# Copyright (C) 2010, Douglas W. Bell
+# Copyright (C) 2015, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
 # terms of the GNU General Public License, either Version 2 or any later
@@ -14,10 +14,6 @@
 
 import sys
 import re
-try:
-    from __main__ import localEncoding
-except ImportError:
-    localEncoding = 'utf-8'
 import option
 import optiondefaults
 import unitdata
@@ -25,34 +21,39 @@ import unitgroup
 
 usage = [_('Usage:'),
          '',
-         '   convertall [%s]' % _('qt-options'),
+         '   convertall [{0}]'.format(_('qt-options')),
          '',
          _('-or- (non-GUI):'),
-         '   convertall [%s] [%s] %s [%s]' % (_('options'), _('number'),
-                                              _('from_unit'), _('to_unit')),
+         '   convertall [{0}] [{1}] {2} [{3}]'.format(_('options'),
+                                                      _('number'),
+                                                      _('from_unit'),
+                                                      _('to_unit')),
          '',
          _('-or- (non-GUI):'),
-         '   convertall -i [%s]' % _('options'),
+         '   convertall -i [{0}]'.format(_('options')),
          '',
          _('Units with spaces must be "quoted"'),
          '',
          _('Options:'),
-         '   -d, --decimals=%-6s %s' %
-             (_('num'), _('set number of decimals to show')),
-         '   -f, --fixed-decimals  %s' %
-             _('show set number of decimals, even if zeros'),
-         '   -h, --help            %s' %
-             _('display this message and exit'),
-         '   -i, --interactive     %s' %
-             _('interactive command line mode (non-GUI)'),
-         '   -q, --quiet           %s' %
-             _('convert without further prompts'),
-         '   -s, --sci-notation    %s' %
-             _('show results in scientific notation'),
+         '   -d, --decimals={0:6} {1}'.format(_('num'),
+                                          _('set number of decimals to show')),
+         '   -f, --fixed-decimals  {0}'.format(
+                              _('show set number of decimals, even if zeros')),
+         '   -s, --sci-notation    {0}'.format(
+                                     _('show results in scientific notation')),
+         '   -e, --eng-notation    {0}'.format(
+                                    _('show results in engineering notation')),
+         '   -h, --help            {0}'.format(
+                                           _('display this message and exit')),
+         '   -i, --interactive     {0}'.format(
+                                 _('interactive command line mode (non-GUI)')),
+         '   -q, --quiet           {0}'.format(
+                                         _('convert without further prompts')),
          '']
 
 def parseArgs(opts, args):
-    """Parse the command line and output conversion results"""
+    """Parse the command line and output conversion results.
+    """
     options = option.Option('convertall', 20)
     options.loadAll(optiondefaults.defaultList)
     quiet = False
@@ -69,9 +70,11 @@ def parseArgs(opts, args):
             except ValueError:
                 pass
         elif opt in ('-f', '--fixed-decimals'):
-            options.changeData('FixedDecimals', 'yes', False)
+            options.changeData('Notation', 'fixed', False)
         elif opt in ('-s', '--sci-notation'):
-            options.changeData('SciNotation', 'yes', False)
+            options.changeData('Notation', 'scientific', False)
+        elif opt in ('-e', '--eng-notation'):
+            options.changeData('Notation', 'engineering', False)
         elif opt in ('-q', '--quiet'):
             quiet = True
         elif opt in ('-t', '--test'):
@@ -79,20 +82,20 @@ def parseArgs(opts, args):
     data = unitdata.UnitData()
     try:
         data.readData()
-    except unitdata.UnitDataError, text:
-        print u'Error in unit data - %s' % text
+    except unitdata.UnitDataError as text:
+        print('Error in unit data - {0}'.format(text))
         sys.exit(1)
     if dataTestMode:
         unitDataTest(data, options)
         return
-    numStr = u'1.0'
+    numStr = '1.0'
     if args:
         numStr = args[0]
         try:
             float(numStr)
             del args[0]
         except (ValueError):
-            numStr = u'1.0'
+            numStr = '1.0'
     fromUnit = None
     try:
         fromUnit = getUnit(data, options, args.pop(0))
@@ -110,13 +113,13 @@ def parseArgs(opts, args):
     while True:
         while not fromUnit:
             text = _('Enter from unit -> ')
-            fromText = raw_input(text.encode(localEncoding))
+            fromText = input(text)
             if not fromText:
                 return
             fromUnit = getUnit(data, options, fromText)
         while not toUnit:
             text = _('Enter to unit -> ')
-            toText = raw_input(text.encode(localEncoding))
+            toText = input(text)
             if not toText:
                 return
             toUnit = getUnit(data, options, toText)
@@ -124,16 +127,16 @@ def parseArgs(opts, args):
             badEntry = False
             while True:
                 if not badEntry:
-                    text = u'%s %s = %s %s' % (numStr, fromUnit.unitString(),
-                                             fromUnit.convertStr(float(numStr),
-                                                                 toUnit),
-                                             toUnit.unitString())
-                    print text.encode(localEncoding)
+                    newNumStr = fromUnit.convertStr(float(numStr), toUnit)
+                    print('{0} {1} = {2} {3}'.format(numStr,
+                                                     fromUnit.unitString(),
+                                                     newNumStr,
+                                                     toUnit.unitString()))
                     if quiet:
                         return
                 badEntry = False
                 text = _('Enter number, [n]ew, [r]everse or [q]uit -> ')
-                rep = raw_input(text.encode(localEncoding))
+                rep = input(text)
                 if not rep or rep[0] in ('q', 'Q'):
                     return
                 if rep[0] in ('r', 'R'):
@@ -141,8 +144,8 @@ def parseArgs(opts, args):
                 elif rep[0] in ('n', 'N'):
                     fromUnit = None
                     toUnit = None
-                    numStr = u'1.0'
-                    print
+                    numStr = '1.0'
+                    print()
                     break
                 else:
                     try:
@@ -151,9 +154,8 @@ def parseArgs(opts, args):
                     except ValueError:
                         badEntry = True
         else:
-            text = _(u'Units %s and %s are not compatible') % \
-                         (fromUnit.unitString(), toUnit.unitString())
-            print text.encode(localEncoding)
+            print(_('Units {0} and {1} are not compatible').
+                  format(fromUnit.unitString(), toUnit.unitString()))
             if quiet:
                 return
             fromUnit = None
@@ -161,22 +163,25 @@ def parseArgs(opts, args):
 
 def getUnit(data, options, text):
     """Create unit from text, check unit is valid,
-       return reduced unit or None"""
+       return reduced unit or None.
+    """
     unit = unitgroup.UnitGroup(data, options)
     unit.update(text)
     if unit.groupValid():
         unit.reduceGroup()
         return unit
-    print (_(u'%s is not a valid unit') % text).encode(localEncoding)
+    print(_('{0} is not a valid unit').format(text))
     return None
 
 def printUsage():
-    """Print usage text"""
-    print ('\n'.join(usage)).encode(localEncoding)
+    """Print usage text.
+    """
+    print('\n'.join(usage))
 
 def unitDataTest(data, options):
     """Run through a test of all units for consistent definitions,
-       print results, return True if all pass"""
+       print results, return True if all pass.
+    """
     badUnits = {}
     errorRegEx = re.compile(r'.*"(.*)"$')
     for unit in data.values():
@@ -187,13 +192,12 @@ def unitDataTest(data, options):
         try:
             group.reduceGroup()
         except unitdata.UnitDataError as errorText:
-            rootUnitName = errorRegEx.match(unicode(errorText)).group(1)
+            rootUnitName = errorRegEx.match(errorText).group(1)
             badUnits.setdefault(rootUnitName, []).append(unit.name)
     if not badUnits:
-        print 'All units pass tests'
+        print('All units pass tests')
         return True
     for key in sorted(badUnits.keys()):
         impacts = ', '.join(sorted(badUnits[key]))
-        text = '%s\n   Impacts:  %s\n' % (key, impacts)
-        print text.encode(localEncoding)
+        print('{0}\n   Impacts:  {1}\n'.format(key, impacts))
     return False
