@@ -1,10 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 ****************************************************************************
  convertall.py, the main program file
 
  ConvertAll, a units conversion program
- Copyright (C) 2008, Douglas W. Bell
+ Copyright (C) 2015, Douglas W. Bell
 
  This is free software; you can redistribute it and/or modify it under the
  terms of the GNU General Public License, either Version 2 or any later
@@ -14,7 +14,7 @@
 """
 
 __progname__ = 'ConvertAll'
-__version__ = '0.5.2'
+__version__ = '0.6.1'
 __author__ = 'Doug Bell'
 
 dataFilePath = None    # modified by install script if required
@@ -22,21 +22,20 @@ helpFilePath = None    # modified by install script if required
 iconPath = None        # modified by install script if required
 translationPath = 'translations'
 lang = ''
-localEncoding = ''
 
 import sys
 import os.path
 import locale
 import getopt
 import signal
-import __builtin__
+import builtins
 from PyQt4 import QtCore, QtGui
 
 def loadTranslator(fileName, app):
-    """Load and install qt translator, return True if sucessful"""
+    """Load and install qt translator, return True if sucessful.
+    """
     translator = QtCore.QTranslator(app)
-    modPath = unicode(os.path.abspath(sys.path[0]),
-                      sys.getfilesystemencoding())
+    modPath = os.path.abspath(sys.path[0])
     if modPath.endswith('.zip'):  # for py2exe
         modPath = os.path.dirname(modPath)
     path = os.path.join(modPath, translationPath)
@@ -51,11 +50,13 @@ def loadTranslator(fileName, app):
         QtCore.QCoreApplication.installTranslator(translator)
         return True
     else:
-        print 'Warning: translation file "%s" could not be loaded' % fileName
+        print('Warning: translation file "{0}" could not be loaded'.
+              format(fileName))
         return False
 
 def setupTranslator(app):
-    """Set language, load translators and setup translator function"""
+    """Set language, load translators and setup translator function.
+    """
     try:
         locale.setlocale(locale.LC_ALL, '')
     except locale.Error:
@@ -73,56 +74,38 @@ def setupTranslator(app):
                 lang = ''
     numTranslators = 0
     if lang and lang[:2] not in ['C', 'en']:
-        numTranslators += loadTranslator('qt_%s' % lang, app)
-        numTranslators += loadTranslator('convertall_%s' % lang, app)
+        numTranslators += loadTranslator('qt_{0}'.format(lang), app)
+        numTranslators += loadTranslator('convertall_{0}'.format(lang), app)
 
     def translate(text, comment=''):
         """Translation function that sets context to calling module's
-           filename"""
+           filename.
+        """
         try:
             frame = sys._getframe(1)
             fileName = frame.f_code.co_filename
         finally:
             del frame
         context = os.path.basename(os.path.splitext(fileName)[0])
-        return unicode(QtCore.QCoreApplication.translate(context, text,
-                                                         comment))
+        return QtCore.QCoreApplication.translate(context, text, comment)
 
     def markNoTranslate(text, comment=''):
         return text
 
     if numTranslators:
-        __builtin__._ = translate
+        builtins._ = translate
     else:
-        __builtin__._ = markNoTranslate
-
-def setLocalEncoding():
-    """Store locale's default text encoding for console messages"""
-    global localEncoding
-    try:
-        # not reliable?
-        localEncoding = locale.getpreferredencoding()
-        'test'.encode(localEncoding)
-    except (AttributeError, LookupError, TypeError, locale.Error):
-        try:
-            # not available on windows
-            localEncoding = locale.nl_langinfo(locale.CODESET)
-            'test'.encode(localEncoding)
-        except (AttributeError, LookupError, TypeError, locale.Error):
-            try:
-                localEncoding = locale.getdefaultlocale()[1]
-                'test'.encode(localEncoding)
-            except (AttributeError, LookupError, TypeError, locale.Error):
-                localEncoding = 'utf-8'
+        builtins._ = markNoTranslate
 
 
 def main():
     if len(sys.argv) > 1:
         try:
-            opts, args = getopt.gnu_getopt(sys.argv, 'd:fhiqst', 
+            opts, args = getopt.gnu_getopt(sys.argv, 'd:fhiqset',
                                            ['decimals=', 'fixed-decimals',
                                             'help', 'interactive', 'quiet',
-                                            'sci-notation', 'test'])
+                                            'sci-notation', 'eng-notation',
+                                            'test'])
         except getopt.GetoptError:
             # check that arguments aren't Qt GUI options
             if sys.argv[1][:3] not in ['-ba', '-bg', '-bt', '-bu', '-cm',
@@ -132,14 +115,12 @@ def main():
                                        '-sy', '-ti', '-vi', '-wi']:
                 app = QtCore.QCoreApplication(sys.argv)
                 setupTranslator(app)
-                setLocalEncoding()
                 import cmdline
                 cmdline.printUsage()
                 sys.exit(2)
         else:
             app = QtCore.QCoreApplication(sys.argv)
             setupTranslator(app)
-            setLocalEncoding()
             import cmdline
             try:
                 cmdline.parseArgs(opts, args[1:])
@@ -149,7 +130,6 @@ def main():
     userStyle = '-style' in ' '.join(sys.argv)
     app = QtGui.QApplication(sys.argv)
     setupTranslator(app)  # must be before importing any convertall modules
-    setLocalEncoding()
     import convertdlg
     if not userStyle and not sys.platform.startswith('win'):
         QtGui.QApplication.setStyle('plastique')
