@@ -1,10 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 #****************************************************************************
 # unitatom.py, provides class to hold data on each available unit
 #
 # ConvertAll, a units conversion program
-# Copyright (C) 2006, Douglas W. Bell
+# Copyright (C) 2014, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
 # terms of the GNU General Public License, either Version 2 or any later
@@ -18,7 +18,8 @@ import unitdata
 
 
 class UnitAtom(object):
-    """Reads and stores a single unit conversion"""
+    """Reads and stores a single unit conversion.
+    """
     partialExp = 1000
     badOpRegEx = re.compile(r'[^\d\.eE\+\-\*/]')
     eqnRegEx = re.compile(r'\[(.*?)\](.*)')
@@ -41,8 +42,8 @@ class UnitAtom(object):
                         self.toEqn = self.toEqn.strip()
                     self.fromEqn = self.fromEqn.strip()
                 except AttributeError:
-                    raise unitdata.UnitDataError, \
-                          _('Bad equation for "%s"') % self.name
+                    raise unitdata.UnitDataError(_('Bad equation for "{0}"').
+                                                 format(self.name))
             else:                # split factor and equiv unit for linear
                 parts = self.equiv.split(None, 1)
                 if len(parts) > 1 and \
@@ -54,41 +55,45 @@ class UnitAtom(object):
                     except:
                         pass
         self.comments = [comm.strip() for comm in dataList]
-        self.comments.extend([u''] * (2 - len(self.comments)))
+        self.comments.extend([''] * (2 - len(self.comments)))
         self.exp = 1
         self.viewLink = [None, None]
         self.typeName = ''
 
     def description(self):
-        """Return name and 1st comment (usu. full name) if applicable"""
+        """Return name and 1st comment (usu. full name) if applicable.
+        """
         if self.comments[0]:
-            return u'%s  (%s)' % (self.name, self.comments[0])
+            return '{0}  ({1})'.format(self.name, self.comments[0])
         return self.name
 
     def unitValid(self):
-        """Return True if unit and exponent are valid"""
+        """Return True if unit and exponent are valid.
+        """
         if self.equiv and \
                 -UnitAtom.partialExp < self.exp < UnitAtom.partialExp:
             return True
         return False
 
     def unitText(self, absExp=False):
-        """Return text for unit name with exponent or absolute value of exp"""
+        """Return text for unit name with exponent or absolute value of exp.
+        """
         exp = self.exp
         if absExp:
             exp = abs(self.exp)
         if exp == 1:
             return self.name
         if -UnitAtom.partialExp < exp < UnitAtom.partialExp:
-            return u'%s^%d' % (self.name, exp)
+            return '{0}^{1}'.format(self.name, exp)
         if exp > 1:
-            return u'%s^' % self.name
+            return '{0}^'.format(self.name)
         else:
-            return u'%s^-' % self.name
+            return '{0}^-'.format(self.name)
 
     def matchWords(self, wordList):
-        """Return True if unit name and comments match word list"""
-        dataStr = u' '.join((self.name, self.comments[0],
+        """Return True if unit name and comments match word list.
+        """
+        dataStr = ' '.join((self.name, self.comments[0],
                              self.comments[1])).lower()
         for word in wordList:
             if dataStr.find(word) == -1:
@@ -96,8 +101,16 @@ class UnitAtom(object):
         return True
 
     def copy(self):
-        """Return a copy of the unit so the exponent can be changed"""
+        """Return a copy of the unit so the exponent can be changed.
+        """
         return copy.copy(self)
 
-    def __cmp__(self, other):
-        return cmp(self.name.lower(), other.name.lower())
+    def __lt__(self, other):
+        """Less than comparison for sorting.
+        """
+        return self.name.lower() < other.name.lower()
+
+    def __eq__(self, other):
+        """Equality test.
+        """
+        return self.name.lower() == other.name.lower()
